#ifndef NT2_INCLUDE_FUNCTIONS_IFIX_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IFIX_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/ifix.hpp>

#endif
